@@ -12,6 +12,7 @@ set -o errexit
 . $BASE_DEVSTACK_DIR/stackrc # needed for status directory
 
 . $BASE_DEVSTACK_DIR/lib/tls
+. $BASE_DEVSTACK_DIR/lib/apache
 . ${GITDIR[sahara]}/devstack/plugin.sh
 
 set -o xtrace
@@ -20,4 +21,4 @@ export ENABLED_SERVICES+=,sahara-api,sahara-eng,
 stop_sahara
 
 # sanity check that service is actually down
-ensure_services_stopped sahara-api sahara-eng
+ensure_services_stopped sahara-eng
