@@ -17,12 +17,6 @@ from sahara.common.policies import base
 
 
 images_policies = [
-    policy.DocumentedRuleDefault(
-        name=base.DATA_PROCESSING_IMAGES % 'set_tags',
-        check_str=base.UNPROTECTED,
-        description='Add tags to image.',
-        operations=[{'path': '/v2/images/{image_id}/tags',
-                     'method': 'PUT'}]),
     policy.DocumentedRuleDefault(
         name=base.DATA_PROCESSING_IMAGES % 'add_tags',
         check_str=base.UNPROTECTED,
@@ -34,45 +28,30 @@ images_policies = [
         check_str=base.UNPROTECTED,
         description='Register image.',
         operations=[{'path': '/v1.1/{project_id}/images/{image_id}',
-                     'method': 'POST'},
-                    {'path': '/v2/images/{image_id}',
                      'method': 'POST'}]),
     policy.DocumentedRuleDefault(
         name=base.DATA_PROCESSING_IMAGES % 'get_all',
         check_str=base.UNPROTECTED,
         description='List images.',
-        operations=[{'path': '/v1.1/{project_id}/images', 'method': 'GET'},
-                    {'path': '/v2/images', 'method': 'GET'}]),
+        operations=[{'path': '/v1.1/{project_id}/images', 'method': 'GET'}]),
     policy.DocumentedRuleDefault(
         name=base.DATA_PROCESSING_IMAGES % 'unregister',
         check_str=base.UNPROTECTED,
         description='Unregister image.',
         operations=[{'path': '/v1.1/{project_id}/images/{image_id}',
-                     'method': 'POST'},
-                    {'path': '/v2/images/{image_id}',
-                     'method': 'DELETE'}]),
+                     'method': 'POST'}]),
     policy.DocumentedRuleDefault(
         name=base.DATA_PROCESSING_IMAGES % 'get',
         check_str=base.UNPROTECTED,
         description='Show image details.',
         operations=[{'path': '/v1.1/{project_id}/images/{image_id}',
-                     'method': 'GET'},
-                    {'path': '/v2/images/{image_id}',
                      'method': 'GET'}]),
     policy.DocumentedRuleDefault(
         name=base.DATA_PROCESSING_IMAGES % 'remove_tags',
         check_str=base.UNPROTECTED,
         description='Remove tags from image.',
         operations=[{'path': '/v1.1/{project_id}/images/{image_id}/untag',
-                     'method': 'POST'},
-                    {'path': '/v2/images/{image_id}/tags',
-                     'method': 'DELETE'}]),
-    policy.DocumentedRuleDefault(
-        name=base.DATA_PROCESSING_IMAGES % 'get_tags',
-        check_str=base.UNPROTECTED,
-        description='List tags on an image.',
-        operations=[{'path': '/v2/images/{image_id}/tags',
-                     'method': 'GET'}]),
+                     'method': 'POST'}]),
 ]
 
 
