@@ -15,6 +15,7 @@
 
 import testtools
 
+from sahara import main
 from sahara.plugins import base as pb
 
 
@@ -22,11 +23,9 @@ class BasePluginsSupportTest(testtools.TestCase):
 
     def setUp(self):
         super(BasePluginsSupportTest, self).setUp()
+        main.CONF.set_override('plugins', ['fake', 'cdh', 'spark'])
         pb.setup_plugins()
 
     def test_plugins_loaded(self):
         plugins = [p.name for p in pb.PLUGINS.get_plugins()]
-        self.assertIn('vanilla', plugins)
-        self.assertIn('spark', plugins)
-        self.assertIn('cdh', plugins)
-        self.assertIn('ambari', plugins)
+        self.assertIn('fake', plugins)
