@@ -14,8 +14,8 @@
 # limitations under the License.
 
 import datetime
+from unittest import mock
 
-import mock
 from oslo_utils import timeutils
 
 from sahara.conductor import manager
@@ -51,11 +51,11 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
                                    job, ds, ds)
         p._make_periodic_tasks().update_job_statuses(None)
         self.assertEqual(2, get_job_status.call_count)
-        get_job_status.assert_has_calls([mock.call(u'2'),
-                                         mock.call(u'3')])
+        get_job_status.assert_has_calls([mock.call('2'),
+                                         mock.call('3')])
 
     @mock.patch('sahara.service.trusts.use_os_admin_auth_token')
-    @mock.patch('sahara.service.api.terminate_cluster')
+    @mock.patch('sahara.service.api.v10.terminate_cluster')
     def test_transient_cluster_terminate(self, terminate_cluster,
                                          use_os_admin_auth_token):
 
@@ -85,10 +85,10 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
         p._make_periodic_tasks().terminate_unneeded_transient_clusters(None)
         self.assertEqual(1, terminate_cluster.call_count)
-        terminate_cluster.assert_has_calls([mock.call(u'1')])
+        terminate_cluster.assert_has_calls([mock.call('1')])
         self.assertEqual(1, use_os_admin_auth_token.call_count)
 
-    @mock.patch('sahara.service.api.terminate_cluster')
+    @mock.patch('sahara.service.api.v10.terminate_cluster')
     def test_not_transient_cluster_does_not_terminate(self, terminate_cluster):
 
         timeutils.set_time_override(datetime.datetime(2005, 2, 1, 0, 0))
@@ -98,7 +98,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
         self.assertEqual(0, terminate_cluster.call_count)
 
-    @mock.patch('sahara.service.api.terminate_cluster')
+    @mock.patch('sahara.service.api.v10.terminate_cluster')
     def test_transient_cluster_not_killed_too_early(self, terminate_cluster):
 
         timeutils.set_time_override(datetime.datetime(2005, 2, 1, second=0))
@@ -111,7 +111,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
         self.assertEqual(0, terminate_cluster.call_count)
 
     @mock.patch('sahara.service.trusts.use_os_admin_auth_token')
-    @mock.patch('sahara.service.api.terminate_cluster')
+    @mock.patch('sahara.service.api.v10.terminate_cluster')
     def test_transient_cluster_killed_in_time(self, terminate_cluster,
                                               use_os_admin_auth_token):
 
@@ -123,10 +123,10 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
         p._make_periodic_tasks().terminate_unneeded_transient_clusters(None)
         self.assertEqual(1, terminate_cluster.call_count)
-        terminate_cluster.assert_has_calls([mock.call(u'1')])
+        terminate_cluster.assert_has_calls([mock.call('1')])
         self.assertEqual(1, use_os_admin_auth_token.call_count)
 
-    @mock.patch('sahara.service.api.terminate_cluster')
+    @mock.patch('sahara.service.api.v10.terminate_cluster')
     def test_incomplete_cluster_not_killed_too_early(self, terminate_cluster):
 
         self.override_config('cleanup_time_for_incomplete_clusters', 1)
@@ -142,7 +142,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
         self.assertEqual(0, terminate_cluster.call_count)
 
     @mock.patch('sahara.service.trusts.use_os_admin_auth_token')
-    @mock.patch('sahara.service.api.terminate_cluster')
+    @mock.patch('sahara.service.api.v10.terminate_cluster')
     def test_incomplete_cluster_killed_in_time(self, terminate_cluster,
                                                use_os_admin_auth_token):
 
@@ -156,10 +156,10 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
         p._make_periodic_tasks().terminate_incomplete_clusters(None)
         self.assertEqual(1, terminate_cluster.call_count)
-        terminate_cluster.assert_has_calls([mock.call(u'1')])
+        terminate_cluster.assert_has_calls([mock.call('1')])
         self.assertEqual(1, use_os_admin_auth_token.call_count)
 
-    @mock.patch('sahara.service.api.terminate_cluster')
+    @mock.patch('sahara.service.api.v10.terminate_cluster')
     def test_active_cluster_not_killed_as_inactive(
             self, terminate_cluster):
         self.override_config('cleanup_time_for_incomplete_clusters', 1)
@@ -210,7 +210,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
     @mock.patch(
         'sahara.service.health.verification_base.validate_verification_start')
-    @mock.patch('sahara.service.api.update_cluster')
+    @mock.patch('sahara.service.api.v10.update_cluster')
     def test_run_verifications_executed(self, cluster_update, ver_valid):
         self._make_cluster('1')
         p._make_periodic_tasks().run_verifications(None)
@@ -220,7 +220,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
     @mock.patch(
         'sahara.service.health.verification_base.validate_verification_start')
-    @mock.patch('sahara.service.api.update_cluster')
+    @mock.patch('sahara.service.api.v10.update_cluster')
     def test_run_verifications_not_executed(self, cluster_update, ver_valid):
         self._make_cluster('1', status=c_u.CLUSTER_STATUS_ERROR)
         p._make_periodic_tasks().run_verifications(None)
