@@ -13,13 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import re
 import traceback
 
 import flask
+import microversion_parse
 from oslo_log import log as logging
 from oslo_middleware import request_id as oslo_req_id
+import six
 from werkzeug import datastructures
 
+from sahara.api import microversion as mv
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
@@ -53,7 +57,7 @@ class Rest(flask.Blueprint):
         return self._mroute('PATCH', rule, status_code)
 
     def _mroute(self, methods, rule, status_code=None, **kw):
-        if type(methods) is str:
+        if isinstance(methods, six.string_types):
             methods = [methods]
         return self.route(rule, methods=methods, status_code=status_code, **kw)
 
@@ -113,7 +117,27 @@ class Rest(flask.Blueprint):
         return decorator
 
 
+def check_microversion_header():
+    requested_version = get_requested_microversion()
+    if not re.match(mv.VERSION_STRING_REGEX, requested_version):
+        bad_request_microversion(requested_version)
+    if requested_version not in mv.API_VERSIONS:
+        not_acceptable_microversion(requested_version)
+
+
+def add_vary_header(response):
+    response.headers[mv.VARY_HEADER] = mv.OPENSTACK_API_VERSION_HEADER
+    response.headers[mv.OPENSTACK_API_VERSION_HEADER] = "{} {}".format(
+        mv.SAHARA_SERVICE_TYPE, get_requested_microversion())
+    return response
+
+
 class RestV2(Rest):
+    def __init__(self, *args, **kwargs):
+        super(RestV2, self).__init__(*args, **kwargs)
+        self.before_request(check_microversion_header)
+        self.after_request(add_vary_header)
+
     def route(self, rule, **options):
         status = options.pop('status_code', None)
         file_upload = options.pop('file_upload', False)
@@ -238,7 +262,8 @@ def request_data():
     if hasattr(flask.request, 'parsed_data'):
         return flask.request.parsed_data
 
-    if not flask.request.content_length > 0:
+    if (flask.request.content_length is None
+            or not flask.request.content_length > 0):
         LOG.debug("Empty body provided in request")
         return dict()
 
@@ -264,6 +289,18 @@ def get_request_args():
     return flask.request.args
 
 
+def get_requested_microversion():
+    requested_version = microversion_parse.get_version(
+        flask.request.headers,
+        mv.SAHARA_SERVICE_TYPE
+    )
+    if requested_version is None:
+        requested_version = mv.MIN_API_VERSION
+    elif requested_version == mv.LATEST:
+        requested_version = mv.MAX_API_VERSION
+    return requested_version
+
+
 def abort_and_log(status_code, descr, exc=None):
     LOG.error("Request aborted with status code {code} and "
               "message '{message}'".format(code=status_code, message=descr))
@@ -274,19 +311,63 @@ def abort_and_log(status_code, descr, exc=None):
     flask.abort(status_code, description=descr)
 
 
-def render_error_message(error_code, error_message, error_name):
+def render_error_message(error_code, error_message, error_name, **msg_kwargs):
     message = {
         "error_code": error_code,
         "error_message": error_message,
         "error_name": error_name
     }
 
+    message.update(**msg_kwargs)
+
     resp = render(message)
     resp.status_code = error_code
 
     return resp
 
 
+def not_acceptable_microversion(requested_version):
+    message = ("Version {} is not supported by the API. "
+               "Minimum is {} and maximum is {}.".format(
+                   requested_version,
+                   mv.MIN_API_VERSION,
+                   mv.MAX_API_VERSION
+               ))
+    resp = render_error_message(
+        mv.NOT_ACCEPTABLE_STATUS_CODE,
+        message,
+        mv.NOT_ACCEPTABLE_STATUS_NAME,
+        max_version=mv.MAX_API_VERSION,
+        min_version=mv.MIN_API_VERSION
+    )
+    flask.abort(resp)
+
+
+def bad_request_microversion(requested_version):
+    message = ("API Version String {} is of invalid format. Must be of format"
+               " MajorNum.MinorNum.").format(requested_version)
+    resp = render_error_message(
+        mv.BAD_REQUEST_STATUS_CODE,
+        message,
+        mv.BAD_REQUEST_STATUS_NAME,
+        max_version=mv.MAX_API_VERSION,
+        min_version=mv.MIN_API_VERSION
+    )
+    flask.abort(resp)
+
+
+def invalid_param_error(status_code, descr, exc=None):
+    LOG.error("Request aborted with status code {code} and "
+              "message '{message}'".format(code=status_code, message=descr))
+
+    if exc is not None:
+        LOG.error(traceback.format_exc())
+
+    error_code = "INVALID_PARAMS_ON_REQUEST"
+
+    return render_error_message(status_code, descr, error_code)
+
+
 def internal_error(status_code, descr, exc=None):
     LOG.error("Request aborted with status code {code} and "
               "message '{message}'".format(code=status_code, message=descr))
@@ -348,3 +429,13 @@ def to_wrapped_dict_no_render(func, id, *args, **kwargs):
 
         return not_found(e)
     return obj.to_wrapped_dict()
+
+
+def _replace_hadoop_version_plugin_version(obj):
+    dict.update(obj, {'plugin_version': obj['hadoop_version']})
+    dict.pop(obj, 'hadoop_version')
+
+
+def _replace_tenant_id_project_id(obj):
+    dict.update(obj, {'project_id': obj['tenant_id']})
+    dict.pop(obj, 'tenant_id')
