@@ -89,9 +89,11 @@ JOB_TYPES_ACCEPTABLE_CONFIGS = {
 
 # job actions
 JOB_ACTION_SUSPEND = 'suspend'
+JOB_ACTION_CANCEL = 'cancel'
 
 JOB_ACTION_TYPES_ACCEPTABLE = [
-    JOB_ACTION_SUSPEND
+    JOB_ACTION_SUSPEND,
+    JOB_ACTION_CANCEL
 ]
 
 ADAPT_FOR_OOZIE = 'edp.java.adapt_for_oozie'
